/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



#include "domstubs.idl"
interface nsIDOMGeoGeolocation;

/**
 * Property that extends the navigator object.
 */
[scriptable, uuid(9F218D6A-42EC-4B8A-AEE9-E29CA96A4EAE)]
interface nsIDOMNavigatorGeolocation : nsISupports
{
  readonly attribute nsIDOMGeoGeolocation geolocation;
};

