
/*
 * Copyright 2010 Google Inc.
 *
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */



#ifndef GrMatrix_DEFINED
#define GrMatrix_DEFINED

#include "GrRect.h"
#include "SkMatrix.h"

typedef SkMatrix GrMatrix;

#endif
