/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMSVGAnimatedNumber interface is the interface to an SVG
 * Animated Number.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/SVG11/types.html
 *
 */

interface nsIDOMSVGNumber;

[scriptable, uuid(716e3b11-b03b-49f7-b82d-5383922b0ab3)]
interface nsIDOMSVGAnimatedNumber : nsISupports
{
  attribute float baseVal;
      // raises DOMException on setting
  readonly attribute float animVal;
};


