/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[scriptable, builtinclass, uuid(0e4d1751-fdcd-4ee6-b82d-d3f5d992370d)]
interface nsIDOMDeviceLightEvent : nsIDOMEvent
{
  [noscript] void initDeviceLightEvent(in DOMString eventTypeArg,
                                       in boolean canBubbleArg,
                                       in boolean cancelableArg,
                                       in double value);

  readonly attribute double value;
};

dictionary DeviceLightEventInit : EventInit
{
   double value;
};
