/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "domstubs.idl"

[scriptable, uuid(27b00295-349c-429f-ad0c-87b859e77130)]

interface nsIHTMLObjectResizeListener : nsISupports
{
  /**
   * Listener's callback called by the editor when the user
   * starts resizing an element
   * @param aElement [IN] the element
   */
  void onStartResizing(in nsIDOMElement aElement);

  /**
   * Listener's callback called by the editor when the user
   * has finalized the resizing of an element
   * @param aElement [IN] the element that was resized
   * @param aOldWidth  [IN] the width of the element before resizing
   * @param aOldHeight [IN] the height of the element before resizing
   * @param aNewWidth  [IN] the width of the element after resizing
   * @param aNewHeight [IN] the height of the element after resizing
   */
  void onEndResizing(in nsIDOMElement aElement,
                     in long aOldWidth, in long aOldHeight,
                     in long aNewWidth, in long aNewHeight);
                   
};
