/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMNodeSelector interface is an interface for getting nodes
 * that match a given CSS selector.
 *
 * For more information on this interface please see 
 * <http://dev.w3.org/2006/webapi/selectors-api/>
 */
[scriptable, uuid(7cebc153-168a-416c-ba5a-56a8c2ddb2ec)]
interface nsIDOMNodeSelector : nsISupports
{
  nsIDOMElement querySelector([Null(Stringify)] in DOMString selectors);
  nsIDOMNodeList querySelectorAll([Null(Stringify)] in DOMString selectors);
};
